==> mrpt_1.0.2.orig.tar.gz: mrpt-1.0.2/libs/srba/include/mrpt/srba/models/kf2kf_poses.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

#pragma once

#include <mrpt/poses/CPose3D.h>
#include <mrpt/poses/CPose2D.h>
#include <mrpt/poses/SE_traits.h>

namespace mrpt { namespace srba {
namespace kf2kf_poses
{
	/** \defgroup mrpt_srba_kf2kf KF-to-KF relative pose parameterizations
		* \ingroup mrpt_srba_grp */

	/** \addtogroup mrpt_srba_kf2kf
		* @{ */


	struct SE3
	{
		static const size_t REL_POSE_DIMS = 6;  //!< Each relative pose is parameterized as a CPose3D()
		typedef mrpt::poses::CPose3D       pose_t;  //!< The pose class
		typedef mrpt::poses::SE_traits<3>  se_traits_t;  //!< The SE(3) traits struct (for Lie algebra log/exp maps, etc.)
	};

	struct SE2
	{
		static const size_t REL_POSE_DIMS = 3;  //!< Each relative pose is parameterized as a CPose3D()
		typedef mrpt::poses::CPose2D   pose_t;  //!< The pose class
		typedef mrpt::poses::SE_traits<2>  se_traits_t;  //!< The SE(2) traits struct (for Lie algebra log/exp maps, etc.)
	};

	/** @} */

}
} } // end NS

==> mrpt_1.2.2.orig.tar.gz: mrpt-1.2.2/libs/srba/include/mrpt/srba/models/kf2kf_poses.h <==
/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
   | See: http://www.mrpt.org/Authors - All rights reserved.                   |
   | Released under BSD License. See details in http://www.mrpt.org/License    |
   +---------------------------------------------------------------------------+ */

#pragma once

#include <mrpt/poses/CPose3D.h>
#include <mrpt/poses/CPose2D.h>
#include <mrpt/poses/SE_traits.h>

namespace mrpt { namespace srba {
namespace kf2kf_poses
{
	/** \defgroup mrpt_srba_kf2kf KF-to-KF relative pose parameterizations
		* \ingroup mrpt_srba_grp */

	/** \addtogroup mrpt_srba_kf2kf
		* @{ */


	struct SE3
	{
		static const size_t REL_POSE_DIMS = 6;  //!< Each relative pose is parameterized as a CPose3D()
		typedef mrpt::poses::CPose3D       pose_t;  //!< The pose class
		typedef mrpt::poses::SE_traits<3>  se_traits_t;  //!< The SE(3) traits struct (for Lie algebra log/exp maps, etc.)
	};

	struct SE2
	{
		static const size_t REL_POSE_DIMS = 3;  //!< Each relative pose is parameterized as a CPose3D()
		typedef mrpt::poses::CPose2D   pose_t;  //!< The pose class
		typedef mrpt::poses::SE_traits<2>  se_traits_t;  //!< The SE(2) traits struct (for Lie algebra log/exp maps, etc.)
	};

	/** @} */

}
} } // end NS
